
- screening form: willing to consent should flag subject as ineligible and link to refusal
  form
- refusal form: unable to save
- get error when opening cannot open an .1 visit
- glucose form complains about diagnosis is not relevant
- LLN / ULN ranges, check how this is handled
- allow for past consent datetime for those screened on paper (about 29)
- add normal range and grading for CHOL
